---
title: Grouping
page_title: Grouping - MultiColumnComboBox - Kendo UI for Vue
description: "Group the data during input while using the Kendo UI MultiColumnComboBox wrapper for Vue."
slug: grouping_multicolumncombobox
position: 6
---

# Grouping

Grouping allows you to display data items which are categorized by a specific model field.

> * The grouped data is sorted either in ascending or descending order.
> * To group the data in a specific (custom) order, use [server grouping](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource#configuration-serverGrouping).

For more information on the grouping functionality of the Data Source, refer to the article on the [`group`](https://docs.telerik.com/kendo-ui/api/javascript/data/datasource#configuration-group) configuration.

To configure the rendering of the group titles, use the [`groupTemplate`](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox/configuration/grouptemplate) and [`fixedGroupedTemplate`](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox/configuration/fixedgrouptemplate) templates of the component.

{% meta height:350 %}
```html-preview
<div id="vueapp" class="vue-app">
    <kendo-datasource ref="datasource"
                      :type="'odata'"
                      :transport-read-url="'https://demos.telerik.com/kendo-ui/service/Northwind.svc/Customers'"
                      :group-field="'Country'">
    </kendo-datasource>
    <kendo-multicolumncombobox :data-source-ref="'datasource'"
                               :data-text-field="'ContactName'"
                               :data-value-field="'CustomerID'"
                               :height="260"
                               style="width:400px">
        <kendo-multicolumncombobox-column :field="'ContactName'"
                                          :title="'Name'">
        </kendo-multicolumncombobox-column>
        <kendo-multicolumncombobox-column :field="'CustomerID'"
                                          :title="'ID'">
        </kendo-multicolumncombobox-column>
    </kendo-multicolumncombobox>
</div>
```
```js
Vue.use(DropdownsInstaller);
Vue.use(DataSourceInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {}
    }
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI MultiColumnComboBox for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/multicolumncombobox/overview)
* [API Reference of the MultiColumnComboBox Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/multicolumncombobox)
